==> neuroflex-0.1.2.tar.gz: neuroflex-0.1.2/NeuroFlex/bci_integration/neuro_data_integration.py <==
import numpy as np
from typing import List, Dict, Any
from .bci_processing import BCIProcessor

class NeuroDataIntegrator:
    def __init__(self, bci_processor: BCIProcessor):
        self.bci_processor = bci_processor
        self.integrated_data = {}

    def integrate_eeg_data(self, raw_eeg_data: np.ndarray) -> Dict[str, np.ndarray]:
        """
        Integrate EEG data using the BCIProcessor and store the results.
        """
        processed_data = self.bci_processor.process(raw_eeg_data)
        self.integrated_data['eeg'] = processed_data
        return processed_data

    def integrate_external_data(self, data_type: str, data: np.ndarray) -> None:
        """
        Integrate external data (e.g., fMRI, MEG) with the existing EEG data.
        """
        self.integrated_data[data_type] = data

    def get_integrated_data(self) -> Dict[str, Any]:
        """
        Retrieve the integrated data.
        """
        return self.integrated_data

    def perform_multimodal_analysis(self) -> Dict[str, Any]:
        """
        Perform analysis on the integrated multimodal data.
        """
        # Placeholder for multimodal analysis
        # This method should be implemented based on specific research requirements
        results = {}
        for data_type, data in self.integrated_data.items():
            if data_type == 'eeg':
                results[data_type] = {
                    'mean_power': {band: np.mean(power) for band, power in data.items()}
                }
            else:
                results[data_type] = {'mean': np.mean(data), 'std': np.std(data)}
        return results

# Example usage
if __name__ == "__main__":
    # Create a BCIProcessor instance
    bci_processor = BCIProcessor(sampling_rate=250, num_channels=32)

    # Create a NeuroDataIntegrator instance
    integrator = NeuroDataIntegrator(bci_processor)

    # Simulate some EEG data
    eeg_data = np.random.randn(2500, 32)  # 10 seconds of data at 250 Hz

    # Integrate EEG data
    integrator.integrate_eeg_data(eeg_data)

    # Simulate some external data (e.g., fMRI)
    fmri_data = np.random.randn(100, 100, 100)  # Example fMRI volume
    integrator.integrate_external_data('fmri', fmri_data)

    # Perform multimodal analysis
    results = integrator.perform_multimodal_analysis()

    print("Multimodal Analysis Results:")
    print(results)

==> neuroflex-0.1.3.tar.gz: neuroflex-0.1.3/NeuroFlex/bci_integration/neuro_data_integration.py <==
import numpy as np
from typing import List, Dict, Any
from .bci_processing import BCIProcessor

class NeuroDataIntegrator:
    def __init__(self, bci_processor: BCIProcessor):
        self.bci_processor = bci_processor
        self.integrated_data = {}

    def integrate_eeg_data(self, raw_eeg_data: np.ndarray, labels: np.ndarray) -> Dict[str, np.ndarray]:
        """
        Integrate EEG data using the BCIProcessor and store the results.
        """
        processed_data = self.bci_processor.process(raw_eeg_data, labels)
        self.integrated_data['eeg'] = processed_data
        return processed_data

    def integrate_external_data(self, data_type: str, data: np.ndarray) -> None:
        """
        Integrate external data (e.g., fMRI, MEG) with the existing EEG data.
        """
        self.integrated_data[data_type] = data

    def get_integrated_data(self) -> Dict[str, Any]:
        """
        Retrieve the integrated data.
        """
        return self.integrated_data

    def perform_multimodal_analysis(self) -> Dict[str, Any]:
        """
        Perform analysis on the integrated multimodal data.
        """
        # Placeholder for multimodal analysis
        # This method should be implemented based on specific research requirements
        results = {}
        for data_type, data in self.integrated_data.items():
            if data_type == 'eeg':
                results[data_type] = {
                    'mean_power': {band: np.mean(power) for band, power in data.items()}
                }
            else:
                results[data_type] = {'mean': np.mean(data), 'std': np.std(data)}
        return results

# Example usage
if __name__ == "__main__":
    # Create a BCIProcessor instance
    bci_processor = BCIProcessor(sampling_rate=250, num_channels=32)

    # Create a NeuroDataIntegrator instance
    integrator = NeuroDataIntegrator(bci_processor)

    # Simulate some EEG data
    eeg_data = np.random.randn(2500, 32)  # 10 seconds of data at 250 Hz

    # Integrate EEG data
    integrator.integrate_eeg_data(eeg_data)

    # Simulate some external data (e.g., fMRI)
    fmri_data = np.random.randn(100, 100, 100)  # Example fMRI volume
    integrator.integrate_external_data('fmri', fmri_data)

    # Perform multimodal analysis
    results = integrator.perform_multimodal_analysis()

    print("Multimodal Analysis Results:")
    print(results)
